==> HCR_01F_L_64.10.0.28.zip: resources/www/configuration.js <==
(function(exports) {
const response_lenght = 10
const queryTimeout = 1000
exports.index_multiply = 0x100
exports.can_nodes_count = 1

exports.data_type_template = function() { return data_type_template }
exports.add_template = function(template)
{
    data_type_template.templates.push(template)
}
let data_type_template = {"templates": [
    {"index": "2081_1","template": "datetime"},
    {"index": "2002_1","template": "combobox", "commands": templates_commands.access_commands_rmo()},
    {"index": "2001_9","template": "change_value", "commands": templates_commands.access_values()},
    {"index": "2002_2","template": "password"},
    {"index": "1018_3","template": "ip_addr"},
    {"index": "1018_2","template": "ip_addr"},
    {"index": "2000_2","template": "ip_addr"},
    {"index": "2000_3","template": "ip_addr"},
    {"index": "2000_6","template": "ip_addr"},
    {"index": "2001_5","template": "battery"},
    {"index": "2001_12","template": "bit_value", "commands": templates_commands.hw_error_flags()},
    {"index": "2001_13","template": "bit_value", "commands": templates_commands.sw_error_flags()},
    {"index": "2143_4","template": "combobox", "commands": templates_commands.parity()},
    {"index": "2143_5","template": "combobox", "commands": templates_commands.stopbits()},
    {"index": "2213_1","template": "combobox", "commands": templates_commands.on_off_values()},
    {"index": "2143_1","template": "combobox", "commands": templates_commands.yes_no_values()},
    {"index": "2143_2","template": "combobox", "commands": templates_commands.baudrate()},
    {"index": "2103_1","template": "combobox", "commands": templates_commands.yes_no_values()},
    {"index": "2103_2","template": "combobox", "commands": templates_commands.CAN_speed()},
    {"index": "221B_2","template": "ip_addr need_restart"},
    {"index": "221B_3","template": "ip_addr"},
    {"index": "221B_4","template": "ip_addr"},
    {"index": "221B_5","template": "ip_addr"},
    {"index": "221B_6","template": "ip_addr"},
    {"index": "1011_1","template": "restore_params"},
    {"index": "5001_1","template": "change_value", "commands": templates_commands.user_app_status()},
    {"index": "5000_2","template": "datetime_simple"},
    {"index": "5000_3","template": "ip_addr"},
    {"index": "2F01_4","template": "change_value", "commands": templates_commands.ota_firmware_info()},
    {"index": "2F01_5","template": "change_value", "commands": templates_commands.ota_firmware_info()},
    {"index": "2F02_1","template": "combobox", "commands": templates_commands.ota_update_firmware(), "add_class": "without_undetermined"},
    {"index": "2F03_1","template": "combobox", "commands": templates_commands.ota_firmware_command()},
]}

exports.hide_fields_indexes = [
    {type: "one_field", index: 0x2001, sub: 5},
    {type: "one_field", index: 0x2081, sub: 1},
    //{type: "multy_sub", index: 0x0001, count: 5},
    //{type: "multy_index", index: 0x3F27, count: 10, index_multiply: 0x100},
    //{type: "multy_sub", index: 0x3F26, count: 5},
	//{type: "multy_index", index: 0x001, count: 10, index_multiply: 0x100},
]

exports.get_multiply_templates = function() { return multiply_templates }
exports.add_multiply_templates = function(template)
{
    multiply_templates.push(template)
}
let multiply_templates = []

exports.response_lenght = function() { return response_lenght}
exports.queryTimeout = function() { return queryTimeout}

})(this.configuration = {})

==> HCR_01F_L_64.10.0.35.zip: resources/www/configuration.js <==
(function(exports) {
const response_lenght = 10
const queryTimeout = 1000
exports.index_multiply = 0x100
exports.can_nodes_count = 1
exports.one_wire_scan_timeout = 1000

exports.data_type_template = function() { return data_type_template }
exports.add_template = function(template)
{
    data_type_template.templates.push(template)
}
let data_type_template = {"templates": [
    {"index": "2081_1","template": "datetime"},
    {"index": "2002_1","template": "combobox", "commands": templates_commands.access_commands_rmo()},
    {"index": "2001_9","template": "change_value", "commands": templates_commands.access_values()},
    {"index": "2002_2","template": "password"},
    {"index": "1018_3","template": "ip_addr"},
    {"index": "1018_2","template": "ip_addr"},
    {"index": "2000_2","template": "ip_addr"},
    {"index": "2000_3","template": "ip_addr"},
    {"index": "2000_6","template": "ip_addr"},
    {"index": "2001_5","template": "battery"},
    {"index": "2001_12","template": "bit_value", "commands": templates_commands.hw_error_flags()},
    {"index": "2001_13","template": "bit_value", "commands": templates_commands.sw_error_flags()},
    {"index": "2143_4","template": "combobox", "commands": templates_commands.parity()},
    {"index": "2143_5","template": "combobox", "commands": templates_commands.stopbits()},
    {"index": "2213_1","template": "combobox", "commands": templates_commands.on_off_values()},
    {"index": "2143_1","template": "combobox", "commands": templates_commands.yes_no_values()},
    {"index": "2143_2","template": "combobox", "commands": templates_commands.baudrate()},
    {"index": "2103_1","template": "combobox", "commands": templates_commands.yes_no_values()},
    {"index": "2103_2","template": "combobox", "commands": templates_commands.CAN_speed()},
    {"index": "221B_2","template": "ip_addr need_restart"},
    {"index": "221B_3","template": "ip_addr"},
    {"index": "221B_4","template": "ip_addr"},
    {"index": "221B_5","template": "ip_addr"},
    {"index": "221B_6","template": "ip_addr"},
    {"index": "1011_1","template": "restore_params"},
    {"index": "4C04_1","template": "combobox", "commands":  templates_commands.yes_no_values()},
	{"index": "4C03_1","template": "combobox", "commands":  templates_commands.one_wire_commands()},
    {"index": "5001_1","template": "change_value", "commands": templates_commands.user_app_status()},
    {"index": "5000_2","template": "datetime_simple"},
    {"index": "5000_3","template": "ip_addr"},
    {"index": "2F01_4","template": "change_value", "commands": templates_commands.ota_firmware_info()},
    {"index": "2F01_5","template": "change_value", "commands": templates_commands.ota_firmware_info()},
    {"index": "2F02_1","template": "combobox", "commands": templates_commands.ota_update_firmware(), "add_class": "without_undetermined"},
    {"index": "2F03_1","template": "combobox", "commands": templates_commands.ota_firmware_command()},
]}

exports.hide_fields_indexes = [
    {type: "one_field", index: 0x2001, sub: 5},
    {type: "one_field", index: 0x2081, sub: 1},
    //{type: "multy_sub", index: 0x0001, count: 5},
    //{type: "multy_index", index: 0x3F27, count: 10, index_multiply: 0x100},
    //{type: "multy_sub", index: 0x3F26, count: 5},
	//{type: "multy_index", index: 0x001, count: 10, index_multiply: 0x100},
]

exports.get_multiply_templates = function() { return multiply_templates }
exports.add_multiply_templates = function(template)
{
    multiply_templates.push(template)
}
let multiply_templates = []

exports.response_lenght = function() { return response_lenght}
exports.queryTimeout = function() { return queryTimeout}

})(this.configuration = {})
